/* Constants.c generated by valac 0.56.19, the Vala compiler
 * generated from Constants.vala, do not modify */

/*
* Copyright (c) 2017 Robert San <robertsanseries@gmail.com>
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public
* License as published by the Free Software Foundation; either
* version 2 of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the
* Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
* Boston, MA 02110-1301 USA
*/

#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gtk/gtk.h>
#include <gobject/gvaluecollector.h>

#define CIANO_CONFIGS_CONSTANTS_PROGRAME_NAME "Ciano"
#define CIANO_CONFIGS_CONSTANTS_ID "com.github.robertsanseries.ciano"
#define CIANO_CONFIGS_CONSTANTS_VERSION "0.1.0"
#define CIANO_CONFIGS_CONSTANTS_APP_YEARS "2017"
#define CIANO_CONFIGS_CONSTANTS_APP_ICON "com.github.robertsanseries.ciano"
#define CIANO_CONFIGS_CONSTANTS_ABOUT_COMMENTS "Multimedia converter for all the format you need."
#define CIANO_CONFIGS_CONSTANTS_TRANSLATOR_CREDITS "Github Translators"
#define CIANO_CONFIGS_CONSTANTS_MAIN_URL "https://robertsanseries.github.io/ciano"
#define CIANO_CONFIGS_CONSTANTS_BUG_URL "https://github.com/robertsanseries/ciano/issues"
#define CIANO_CONFIGS_CONSTANTS_HELP_URL "https://github.com/robertsanseries/ciano/wiki"
#define CIANO_CONFIGS_CONSTANTS_TRANSLATE_URL "https://robertsanseries.github.io/ciano"
#define CIANO_CONFIGS_CONSTANTS_TEXT_FOR_ABOUT_DIALOG_WEBSITE "Website"
#define CIANO_CONFIGS_CONSTANTS_TEXT_FOR_ABOUT_DIALOG_WEBSITE_URL "https://robertsanseries.github.io/ciano"
#define CIANO_CONFIGS_CONSTANTS_URL_CSS "com/github/robertsanseries/ciano/css/style.css"
#define CIANO_CONFIGS_CONSTANTS_DIRECTORY_CIANO "/Ciano"
#define CIANO_CONFIGS_CONSTANTS_WELCOME_VIEW "welcome-view"
#define CIANO_CONFIGS_CONSTANTS_LIST_BOX_VIEW "list-box-view"
#define CIANO_CONFIGS_CONSTANTS_TEXT_MP4 "MP4"
#define CIANO_CONFIGS_CONSTANTS_TEXT_3GP "3GP"
#define CIANO_CONFIGS_CONSTANTS_TEXT_MPG "MPG"
#define CIANO_CONFIGS_CONSTANTS_TEXT_AVI "AVI"
#define CIANO_CONFIGS_CONSTANTS_TEXT_WMV "WMV"
#define CIANO_CONFIGS_CONSTANTS_TEXT_FLV "FLV"
#define CIANO_CONFIGS_CONSTANTS_TEXT_SWF "SWF"
#define CIANO_CONFIGS_CONSTANTS_TEXT_MOV "MOV"
#define CIANO_CONFIGS_CONSTANTS_TEXT_MKV "MKV"
#define CIANO_CONFIGS_CONSTANTS_TEXT_VOB "VOB"
#define CIANO_CONFIGS_CONSTANTS_TEXT_MP3 "MP3"
#define CIANO_CONFIGS_CONSTANTS_TEXT_WMA "WMA"
#define CIANO_CONFIGS_CONSTANTS_TEXT_AMR "AMR"
#define CIANO_CONFIGS_CONSTANTS_TEXT_OGG "OGG"
#define CIANO_CONFIGS_CONSTANTS_TEXT_AAC "AAC"
#define CIANO_CONFIGS_CONSTANTS_TEXT_MMF "MMF"
#define CIANO_CONFIGS_CONSTANTS_TEXT_M4A "M4A"
#define CIANO_CONFIGS_CONSTANTS_TEXT_OPUS "OPUS"
#define CIANO_CONFIGS_CONSTANTS_TEXT_WAV "WAV"
#define CIANO_CONFIGS_CONSTANTS_TEXT_FLAC "FLAC"
#define CIANO_CONFIGS_CONSTANTS_TEXT_AIFF "AIFF"
#define CIANO_CONFIGS_CONSTANTS_TEXT_JPG "JPG"
#define CIANO_CONFIGS_CONSTANTS_TEXT_BMP "BMP"
#define CIANO_CONFIGS_CONSTANTS_TEXT_PNG "PNG"
#define CIANO_CONFIGS_CONSTANTS_TEXT_TIF "TIF"
#define CIANO_CONFIGS_CONSTANTS_TEXT_ICO "ICO"
#define CIANO_CONFIGS_CONSTANTS_TEXT_GIF "GIF"
#define CIANO_CONFIGS_CONSTANTS_TEXT_TGA "TGA"
#define CIANO_CONFIGS_CONSTANTS_TEXT_OGV "OGV"
#define CIANO_CONFIGS_CONSTANTS_TEXT_WEBM "WEBM"
#define CIANO_CONFIGS_CONSTANTS_TEXT_WEBP "WEBP"
#define CIANO_CONFIGS_CONSTANTS_TEXT_AT9 "AT9"
#define CIANO_CONFIGS_CONSTANTS_ABOUT_LICENSE_TYPE GTK_LICENSE_GPL_3_0
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define CIANO_CONFIGS_TYPE_CONSTANTS (ciano_configs_constants_get_type ())
#define CIANO_CONFIGS_CONSTANTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CIANO_CONFIGS_TYPE_CONSTANTS, CianoConfigsConstants))
#define CIANO_CONFIGS_CONSTANTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CIANO_CONFIGS_TYPE_CONSTANTS, CianoConfigsConstantsClass))
#define CIANO_CONFIGS_IS_CONSTANTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CIANO_CONFIGS_TYPE_CONSTANTS))
#define CIANO_CONFIGS_IS_CONSTANTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CIANO_CONFIGS_TYPE_CONSTANTS))
#define CIANO_CONFIGS_CONSTANTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CIANO_CONFIGS_TYPE_CONSTANTS, CianoConfigsConstantsClass))

typedef struct _CianoConfigsConstants CianoConfigsConstants;
typedef struct _CianoConfigsConstantsClass CianoConfigsConstantsClass;
typedef struct _CianoConfigsConstantsPrivate CianoConfigsConstantsPrivate;
typedef struct _CianoConfigsParamSpecConstants CianoConfigsParamSpecConstants;

struct _CianoConfigsConstants {
	GTypeInstance parent_instance;
	volatile int ref_count;
	CianoConfigsConstantsPrivate * priv;
};

struct _CianoConfigsConstantsClass {
	GTypeClass parent_class;
	void (*finalize) (CianoConfigsConstants *self);
};

struct _CianoConfigsParamSpecConstants {
	GParamSpec parent_instance;
};

static gpointer ciano_configs_constants_parent_class = NULL;

VALA_EXTERN gpointer ciano_configs_constants_ref (gpointer instance);
VALA_EXTERN void ciano_configs_constants_unref (gpointer instance);
VALA_EXTERN GParamSpec* ciano_configs_param_spec_constants (const gchar* name,
                                                const gchar* nick,
                                                const gchar* blurb,
                                                GType object_type,
                                                GParamFlags flags);
VALA_EXTERN void ciano_configs_value_set_constants (GValue* value,
                                        gpointer v_object);
VALA_EXTERN void ciano_configs_value_take_constants (GValue* value,
                                         gpointer v_object);
VALA_EXTERN gpointer ciano_configs_value_get_constants (const GValue* value);
VALA_EXTERN GType ciano_configs_constants_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CianoConfigsConstants, ciano_configs_constants_unref)
VALA_EXTERN CianoConfigsConstants* ciano_configs_constants_new (void);
VALA_EXTERN CianoConfigsConstants* ciano_configs_constants_construct (GType object_type);
static void ciano_configs_constants_finalize (CianoConfigsConstants * obj);
static GType ciano_configs_constants_get_type_once (void);

const gchar* CIANO_CONFIGS_CONSTANTS_ABOUT_AUTHORS[1] = {"Robert San <robertsanseries@gmail.com>"};

CianoConfigsConstants*
ciano_configs_constants_construct (GType object_type)
{
	CianoConfigsConstants* self = NULL;
	self = (CianoConfigsConstants*) g_type_create_instance (object_type);
	return self;
}

CianoConfigsConstants*
ciano_configs_constants_new (void)
{
	return ciano_configs_constants_construct (CIANO_CONFIGS_TYPE_CONSTANTS);
}

static void
ciano_configs_value_constants_init (GValue* value)
{
	value->data[0].v_pointer = NULL;
}

static void
ciano_configs_value_constants_free_value (GValue* value)
{
	if (value->data[0].v_pointer) {
		ciano_configs_constants_unref (value->data[0].v_pointer);
	}
}

static void
ciano_configs_value_constants_copy_value (const GValue* src_value,
                                          GValue* dest_value)
{
	if (src_value->data[0].v_pointer) {
		dest_value->data[0].v_pointer = ciano_configs_constants_ref (src_value->data[0].v_pointer);
	} else {
		dest_value->data[0].v_pointer = NULL;
	}
}

static gpointer
ciano_configs_value_constants_peek_pointer (const GValue* value)
{
	return value->data[0].v_pointer;
}

static gchar*
ciano_configs_value_constants_collect_value (GValue* value,
                                             guint n_collect_values,
                                             GTypeCValue* collect_values,
                                             guint collect_flags)
{
	if (collect_values[0].v_pointer) {
		CianoConfigsConstants * object;
		object = collect_values[0].v_pointer;
		if (object->parent_instance.g_class == NULL) {
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		}
		value->data[0].v_pointer = ciano_configs_constants_ref (object);
	} else {
		value->data[0].v_pointer = NULL;
	}
	return NULL;
}

static gchar*
ciano_configs_value_constants_lcopy_value (const GValue* value,
                                           guint n_collect_values,
                                           GTypeCValue* collect_values,
                                           guint collect_flags)
{
	CianoConfigsConstants ** object_p;
	object_p = collect_values[0].v_pointer;
	if (!object_p) {
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
	}
	if (!value->data[0].v_pointer) {
		*object_p = NULL;
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
		*object_p = value->data[0].v_pointer;
	} else {
		*object_p = ciano_configs_constants_ref (value->data[0].v_pointer);
	}
	return NULL;
}

GParamSpec*
ciano_configs_param_spec_constants (const gchar* name,
                                    const gchar* nick,
                                    const gchar* blurb,
                                    GType object_type,
                                    GParamFlags flags)
{
	CianoConfigsParamSpecConstants* spec;
	g_return_val_if_fail (g_type_is_a (object_type, CIANO_CONFIGS_TYPE_CONSTANTS), NULL);
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
	G_PARAM_SPEC (spec)->value_type = object_type;
	return G_PARAM_SPEC (spec);
}

gpointer
ciano_configs_value_get_constants (const GValue* value)
{
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, CIANO_CONFIGS_TYPE_CONSTANTS), NULL);
	return value->data[0].v_pointer;
}

void
ciano_configs_value_set_constants (GValue* value,
                                   gpointer v_object)
{
	CianoConfigsConstants * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, CIANO_CONFIGS_TYPE_CONSTANTS));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, CIANO_CONFIGS_TYPE_CONSTANTS));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
		ciano_configs_constants_ref (value->data[0].v_pointer);
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		ciano_configs_constants_unref (old);
	}
}

void
ciano_configs_value_take_constants (GValue* value,
                                    gpointer v_object)
{
	CianoConfigsConstants * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, CIANO_CONFIGS_TYPE_CONSTANTS));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, CIANO_CONFIGS_TYPE_CONSTANTS));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		ciano_configs_constants_unref (old);
	}
}

static void
ciano_configs_constants_class_init (CianoConfigsConstantsClass * klass,
                                    gpointer klass_data)
{
	ciano_configs_constants_parent_class = g_type_class_peek_parent (klass);
	((CianoConfigsConstantsClass *) klass)->finalize = ciano_configs_constants_finalize;
}

static void
ciano_configs_constants_instance_init (CianoConfigsConstants * self,
                                       gpointer klass)
{
	self->ref_count = 1;
}

static void
ciano_configs_constants_finalize (CianoConfigsConstants * obj)
{
	CianoConfigsConstants * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, CIANO_CONFIGS_TYPE_CONSTANTS, CianoConfigsConstants);
	g_signal_handlers_destroy (self);
}

/**
     * The {@code Constants} class is responsible for defining all 
     * the constants used in the application.
     *
     * @since 0.1.0
     */
static GType
ciano_configs_constants_get_type_once (void)
{
	static const GTypeValueTable g_define_type_value_table = { ciano_configs_value_constants_init, ciano_configs_value_constants_free_value, ciano_configs_value_constants_copy_value, ciano_configs_value_constants_peek_pointer, "p", ciano_configs_value_constants_collect_value, "p", ciano_configs_value_constants_lcopy_value };
	static const GTypeInfo g_define_type_info = { sizeof (CianoConfigsConstantsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) ciano_configs_constants_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (CianoConfigsConstants), 0, (GInstanceInitFunc) ciano_configs_constants_instance_init, &g_define_type_value_table };
	static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
	GType ciano_configs_constants_type_id;
	ciano_configs_constants_type_id = g_type_register_fundamental (g_type_fundamental_next (), "CianoConfigsConstants", &g_define_type_info, &g_define_type_fundamental_info, 0);
	return ciano_configs_constants_type_id;
}

GType
ciano_configs_constants_get_type (void)
{
	static volatile gsize ciano_configs_constants_type_id__once = 0;
	if (g_once_init_enter (&ciano_configs_constants_type_id__once)) {
		GType ciano_configs_constants_type_id;
		ciano_configs_constants_type_id = ciano_configs_constants_get_type_once ();
		g_once_init_leave (&ciano_configs_constants_type_id__once, ciano_configs_constants_type_id);
	}
	return ciano_configs_constants_type_id__once;
}

gpointer
ciano_configs_constants_ref (gpointer instance)
{
	CianoConfigsConstants * self;
	self = instance;
	g_atomic_int_inc (&self->ref_count);
	return instance;
}

void
ciano_configs_constants_unref (gpointer instance)
{
	CianoConfigsConstants * self;
	self = instance;
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
		CIANO_CONFIGS_CONSTANTS_GET_CLASS (self)->finalize (self);
		g_type_free_instance ((GTypeInstance *) self);
	}
}

