/* ColumnEnum.c generated by valac 0.56.19, the Vala compiler
 * generated from ColumnEnum.vala, do not modify */

/*
* Copyright (c) 2017 Robert San <robertsanseries@gmail.com>
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public
* License as published by the Free Software Foundation; either
* version 2 of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the
* Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
* Boston, MA 02110-1301 USA
*/

#include <glib-object.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

typedef enum  {
	CIANO_ENUMS_COLUMN_ENUM_NAME,
	CIANO_ENUMS_COLUMN_ENUM_DIRECTORY,
	CIANO_ENUMS_COLUMN_ENUM_N_COLUMNS
} CianoEnumsColumnEnum;

#define CIANO_ENUMS_TYPE_COLUMN_ENUM (ciano_enums_column_enum_get_type ())

VALA_EXTERN GType ciano_enums_column_enum_get_type (void) G_GNUC_CONST ;

/**
     * The {@code ColumnEnum} enum is responsible for representing
     * the fixed (integer) values of the treeview in DialogConvertFile.
     *
     * @since 0.1.0
     */
static GType
ciano_enums_column_enum_get_type_once (void)
{
	static const GEnumValue values[] = {{CIANO_ENUMS_COLUMN_ENUM_NAME, "CIANO_ENUMS_COLUMN_ENUM_NAME", "name"}, {CIANO_ENUMS_COLUMN_ENUM_DIRECTORY, "CIANO_ENUMS_COLUMN_ENUM_DIRECTORY", "directory"}, {CIANO_ENUMS_COLUMN_ENUM_N_COLUMNS, "CIANO_ENUMS_COLUMN_ENUM_N_COLUMNS", "n-columns"}, {0, NULL, NULL}};
	GType ciano_enums_column_enum_type_id;
	ciano_enums_column_enum_type_id = g_enum_register_static ("CianoEnumsColumnEnum", values);
	return ciano_enums_column_enum_type_id;
}

GType
ciano_enums_column_enum_get_type (void)
{
	static volatile gsize ciano_enums_column_enum_type_id__once = 0;
	if (g_once_init_enter (&ciano_enums_column_enum_type_id__once)) {
		GType ciano_enums_column_enum_type_id;
		ciano_enums_column_enum_type_id = ciano_enums_column_enum_get_type_once ();
		g_once_init_leave (&ciano_enums_column_enum_type_id__once, ciano_enums_column_enum_type_id);
	}
	return ciano_enums_column_enum_type_id__once;
}

